from setuptools import setup, find_packages

setup(
    name='sirv-image',
    version='2.0.0',
    description='Official Python SDK for the Sirv dynamic imaging API. This SDK provides a simple way to request any modified image (dimensions, format, quality, sharpen, crop, watermark etc.) using the 100+ image transformation options in Sirv\'s image optimization service.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='Sirv',
    author_email='support@sirv.com',
    url='https://sirv.github.io/sirv-image-python/',
    project_urls={
        'Source': 'https://github.com/sirv/sirv-image-python',
        'Bug Tracker': 'https://github.com/sirv/sirv-image-python/issues',
    },
    packages=find_packages(),
    python_requires='>=3.8',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        'Topic :: Multimedia :: Graphics',
    ],
    keywords='sirv image video spin zoom gallery cdn srcset responsive',
)
